==> buildpack-client-0.0.12-sources.jar: dev/snowdrop/buildpack/config/PlatformConfigBuilder.java <==
package dev.snowdrop.buildpack.config;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class PlatformConfigBuilder extends dev.snowdrop.buildpack.config.PlatformConfigFluentImpl<dev.snowdrop.buildpack.config.PlatformConfigBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.config.PlatformConfig,dev.snowdrop.buildpack.config.PlatformConfigBuilder>{
  public PlatformConfigBuilder() {
    this(false);
  }
  public PlatformConfigBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent,dev.snowdrop.buildpack.config.PlatformConfig instance) {
    this(fluent, instance, false);
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent,dev.snowdrop.buildpack.config.PlatformConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPlatformLevel(instance.getPlatformLevel()); 
    fluent.withLifecycleImage(instance.getLifecycleImage()); 
    fluent.withEnvironment(instance.getEnvironment()); 
    fluent.withTrustBuilder(instance.getTrustBuilder()); 
    this.validationEnabled = validationEnabled; 
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfig instance) {
    this(instance,false);
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPlatformLevel(instance.getPlatformLevel()); 
    this.withLifecycleImage(instance.getLifecycleImage()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withTrustBuilder(instance.getTrustBuilder()); 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.config.EditablePlatformConfig build() {
    EditablePlatformConfig buildable = new EditablePlatformConfig(fluent.getPlatformLevel(),fluent.getLifecycleImage(),fluent.getEnvironment(),fluent.getTrustBuilder());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlatformConfigBuilder that = (PlatformConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.14-sources.jar: dev/snowdrop/buildpack/config/PlatformConfigBuilder.java <==
package dev.snowdrop.buildpack.config;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class PlatformConfigBuilder extends dev.snowdrop.buildpack.config.PlatformConfigFluentImpl<dev.snowdrop.buildpack.config.PlatformConfigBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.config.PlatformConfig,dev.snowdrop.buildpack.config.PlatformConfigBuilder>{
  public PlatformConfigBuilder() {
    this(false);
  }
  public PlatformConfigBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent,dev.snowdrop.buildpack.config.PlatformConfig instance) {
    this(fluent, instance, false);
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent,dev.snowdrop.buildpack.config.PlatformConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPlatformLevel(instance.getPlatformLevel()); 
    fluent.withLifecycleImage(instance.getLifecycleImage()); 
    fluent.withEnvironment(instance.getEnvironment()); 
    fluent.withTrustBuilder(instance.getTrustBuilder()); 
    fluent.withPhaseDebugScript(instance.getPhaseDebugScript()); 
    this.validationEnabled = validationEnabled; 
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfig instance) {
    this(instance,false);
  }
  public PlatformConfigBuilder(dev.snowdrop.buildpack.config.PlatformConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPlatformLevel(instance.getPlatformLevel()); 
    this.withLifecycleImage(instance.getLifecycleImage()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withTrustBuilder(instance.getTrustBuilder()); 
    this.withPhaseDebugScript(instance.getPhaseDebugScript()); 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.config.PlatformConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.config.EditablePlatformConfig build() {
    EditablePlatformConfig buildable = new EditablePlatformConfig(fluent.getPlatformLevel(),fluent.getLifecycleImage(),fluent.getEnvironment(),fluent.getTrustBuilder(),fluent.getPhaseDebugScript());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlatformConfigBuilder that = (PlatformConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
